% Noise Reduction in Noisy Signal using MATLAB
% Step 1: Load and visualize the noisy signal
fs = 1000; % Sampling frequency (Hz)
t = 0:1/fs:2; % Time vector (2 seconds)
f_noise = 50; % Frequency of noise (Hz)
amplitude = 1; % Amplitude of noise
% Generate noisy signal
noisy_signal = cos(2*pi*10*t) + 0.5*randn(size(t));
% Plot the noisy signal
figure;
subplot(2,1,1);
plot(t, noisy_signal);
title('Noisy Signal');
xlabel('Time (s)');
ylabel('Amplitude');
%CODE
% Step 2: Design a low-pass filter
fc = 100; % Cutoff frequency of the low-pass filter (Hz)
order = 4; % Order of the filter
% Design a low-pass Butterworth filter
[b, a] = butter(order, fc/(fs/2), 'low');
% Step 3: Apply the filter to the noisy signal
filtered_signal = filtfilt(b, a, noisy_signal);
% Plot the filtered signal
subplot(2,1,2);
plot(t, filtered_signal);
title('Filtered Signal');
xlabel('Time (s)');
ylabel('Amplitude');
% Step 4: Compare the original noisy signal with the filtered signal
figure;
plot(t, noisy_signal, 'b', t, filtered_signal, 'r');
title('Comparison: Noisy Signal vs Filtered Signal');
legend('Noisy Signal', 'Filtered Signal');
xlabel('Time (s)');
ylabel('Amplitude');